
from hashlib import sha1
from re import sub

class UrlBuilder:
    def __init__(self, bbbServerBaseUrl, securitySalt):
        self.bbbServerBaseUrl = sub('(\/api)?\/?$', '/api/', bbbServerBaseUrl, 1)
        self.securitySalt = securitySalt

    def buildUrl(self, api_call, params={}):
        url = self.bbbServerBaseUrl
        url += api_call + "?"
        for key, value in params.items():
            if isinstance(value, bool):
                value = "true" if value else "false"
            else:
                value = str(value)
            url += key + "=" + value + "&"

        url += "checksum=" + self.__get_checksum(api_call, params)
        return url

    def __get_checksum(self, api_call, params={}):
        secret_str = api_call
        for key, value in params.items():
            if isinstance(value, bool):
                value = "true" if value else "false"
            else:
                value = str(value)
            secret_str += key + "=" + value + "&"
        if secret_str.endswith("&"):
            secret_str = secret_str[:-1]
        secret_str += self.securitySalt
        return sha1(secret_str.encode('utf-8')).hexdigest()



from .base import BaseResponse
from ..core.meeting import Meeting
import jxmlease

class GetMeetingsResponse(BaseResponse):
    def get_meetings(self):
        meetings = []

        try:
            if self.get_message_key() == "noMeetings":
                return []
        except KeyError:
            pass

        meetings_data = self.get_field("meetings")["meeting"]
        if isinstance(meetings_data, jxmlease.dictnode.XMLDictNode):
            meetings.append(Meeting(meetings_data))
        else:
            for meetingXml in self.get_field("meetings")["meeting"]:
                meetings.append(Meeting(meetingXml))
        return meetings



class Attendee:
    def __init__(self, xml):
        self.__userID = xml["userID"]
        self.__fullName = xml["fullName"]
        self.__role = xml["role"]
        self.__isPresenter = xml["isPresenter"] == 'true'
        self.__isListeningOnly = xml["isListeningOnly"] == 'true'
        self.__hasJoinedVoice = xml["hasJoinedVoice"] == 'true'
        self.__hasVideo = xml["hasVideo"] == 'true'

    def get_userid(self):
        return self.__userID

    def get_fullname(self):
        return self.__fullName

    def get_role(self):
        return self.__role

    def is_presenter(self):
        return self.__isPresenter

    def is_listening_only(self):
        return self.__isListeningOnly

    def has_joined_voice(self):
        return self.__hasJoinedVoice

    def has_video(self):
        return self.__hasVideo




from .apiversion import ApiVersionResponse
from .createmeeting import CreateMeetingResponse
from .deleterecordings import DeleteRecordingsResponse
from .endmeeting import EndMeetingResponse
from .getmeetinginfo import GetMeetingInfoResponse
from .getmeetings import GetMeetingsResponse
from .getrecordings import GetRecordingsResponse
from .ismeetingrunning import IsMeetingRunningResponse
from .publishrecordings import PublishRecordingsResponse
from .setconfigxml import SetConfigXMLResponse
from .updaterecordings import UpdateRecordingsResponse


import sys
from .meeting import Meeting


class MeetingInfo(Meeting):
    def __init__(self, xml):
        if sys.version_info[0] == 2:
            super(MeetingInfo, self).__init__(xml)
        else:
            super().__init__(xml)

        self.__internalMeetingId = xml["internalMeetingID"]
        self.__recording = xml["recording"] == 'true'
        self.__startTime = float(xml["startTime"])
        self.__endTime = float(xml["endTime"])
        self.__maxUsers = xml["maxUsers"]
        self.__moderatorCount = xml["moderatorCount"]

    def get_internal_meetingid(self):
        return self.__internalMeetingId

    def get_start_time(self):
        return self.__startTime

    def get_end_time(self):
        return self.__endTime

    def get_max_users(self):
        return self.__maxUsers

    def get_moderator_count(self):
        return self.__moderatorCount

    def is_recording(self):
        return self.__recording



from .base import BaseResponse

class PublishRecordingsResponse(BaseResponse):
    def is_published(self):
        field = self.get_field("published")
        return field == "true" or (isinstance(field, bool) and field)



from .base import BaseResponse

class UpdateRecordingsResponse(BaseResponse):
    def is_updated(self):
        field = self.get_field("updated")
        return field == "true" or (isinstance(field, bool) and field)